/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.glite.data.transfer;


/**
 * Channel definition
 */
public class Channel {
    /** 
     * The name of the channel to select on
     */
    public String channelName;

    /** 
     * The source site name of the channel. e.g. for CERN it should be "cern.ch".
     * In the case of a non-dedicated site to site link this should be "any".
     */
    public String sourceSite;

    /** 
     * The destination site of the channel. As for sourceSite.
     */
    public String destSite;

    /** 
     * The email contact for the responsbile of the channel.
     */
    public String contact;

    /**
     * Number of concurrent streams allowed on the channel.
     */
    public int numberOfStreams;

    /**
     * Number of concurrent files allowed on the channel.
     */
    public int numberOfFiles;

    /**
     * Current maximum bandwidth (capacity) in Mbits/s.
     */
    public int bandwidth;

    /**
     * The throughput goal for the system to achieve. Mbits/s.
     */
    public int nominalThroughput;

    /** 
     * The operational state of the channel.
     * "Active" means running and accepting jobs.
     * "Drain" means servicing jobs, but not accepting new ones from clients.
     * "Inactive" mean accepting new jobs from clients, but not servicing any new ones.
     * "Stopped" means neither accepting nor servicing jobs.
     */
    public String state;
    
    /**
     * The transfer share for each VO on this channel {VOName,Share}.
     */
    public StringPair[] VOShares;
}
