/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * File: TransferJob.java
 *         
 * Authors: Gavin McCance <gavin.mccance@cern.ch>
 *
 * Version info: $Id: PlacementJob.java,v 1.3 2008/03/17 13:45:37 knienart Exp $
 * Release: $Name:  $
 *
 * Revision history:
 * $Log: PlacementJob.java,v $
 * Revision 1.3  2008/03/17 13:45:37  knienart
 * 3.4 additions - targetDirCheck and urlCopyFirstTxmarkTo added
 *
 * Revision 1.2  2005/04/04 15:42:05  mccance
 * docu update
 *
 * Revision 1.1  2005/04/04 15:21:33  mccance
 * Upped interface to 2.9.0: removed remove. changed a couple of method names. Added FilePlacement and FilePlacement job
 *
 * Revision 1.9  2005/02/21 09:10:02  mccance
 * Interface version 2.4.0.
 *  - updated docu.
 *  - added credential to TransferJob for myproxy passwd.
 *
 * Revision 1.8  2005/02/18 16:10:56  mccance
 * Individual file Transfer params removed from interface.
 *
 * Revision 1.7  2005/02/07 16:40:33  szamsu
 * merging back from RC1
 *
 * Revision 1.6  2004/08/26 10:37:44  mccance
 * remove stterts/getters: having them in causes the serialization to become unreliable subsequently for arrays.
 *
 * Revision 1.5  2004/08/20 08:14:10  mccance
 * updated interfaces to match comments received. Removed start. Expanded explanations.
 *
 * Revision 1.4  2004/08/20 07:25:13  szamsu
 * For the sake of the carnivore design we got rid of beans.
 *
 * Revision 1.3  2004/08/06 09:11:16  mccance
 * Added explicit exception names. Reformated some code.
 *
 * Revision 1.2  2004/07/30 14:37:23  mccance
 * beautify the javadoc.
 *
 * Revision 1.1  2004/07/29 15:32:13  mccance
 * refactored interfaces:
 * filetransfer: internal
 * datascheduler: added, external, matching to LCG
 * fileplacement: extra, same interface as scheduler.
 *
 * Revision 1.1  2004/07/26 11:36:14  mccance
 * Outstanding schoolboy error.. fixed xross module screw up as a result of cp -r with CVS directories...
 *
 * Revision 1.1  2004/07/26 09:50:44  mccance
 * Refactoring interface out of org.glite.data.transfer.
 * Interface updated as a result of discussion with LCG.
 *
 * Revision 1.1.1.1  2004/07/22 11:38:29  mccance
 * Initial import of transfer web servuice module.
 *
 *
 *
 */

package org.glite.data.transfer;

/**
 * Describes the placement job description. It consists of an array of
 * logical files each describing an individual file transfer within the
 * job. sourceSE is the physical source SE that all the logical files
 * must be located on. destSE is the destination SE to transfer to.
 *
 * More complex operations (e.g. arbitrary logical source) are provided
 * by the data scheduler.
 *
 * jobParams are a set of transfer layer specific paramaters tha tare
 * applied to each file transfer (e.g. gridFTP params); this is for future
 * use and is not currently taken into account. The credential is used by the
 * transfer system to retrieve the appropriate proxy for the transfer.
 */
public class PlacementJob {

    public String[] logicalFiles;

    public String sourceSE;

    public String destSE;

    public TransferParams jobParams;

    public String credential;

}
