/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * File: TransferJobStatus.java
 *         
 * Authors: Gavin McCance <gavin.mccance@cern.ch>
 *
 * Version info: $Id: TransferJobSummary.java,v 1.16 2008/03/17 13:45:37 knienart Exp $
 * Release: $Name:  $
 *
 * Revision history:
 * $Log: TransferJobSummary.java,v $
 * Revision 1.16  2008/03/17 13:45:37  knienart
 * 3.4 additions - targetDirCheck and urlCopyFirstTxmarkTo added
 *
 * Revision 1.15  2006/12/14 14:07:26  mccance
 * remove
 *
 * Revision 1.14  2005/07/22 08:55:39  rbritoda
 * updates on documentation. removed not necessary classes in the interface. removed TransferFetcher interface. added setJobPriority method to the FileTransfer/Placement interface.
 *
 * Revision 1.13  2005/07/14 13:31:34  rbritoda
 * changes for new interface. mapping to schema.
 *
 * Revision 1.12  2005/02/22 10:06:00  mccance
 * update docu on interface. State FAILED -> TRANSFERFAILED
 *
 * Revision 1.11  2005/02/21 10:25:05  mccance
 * upped to v2.4.1 - JobState -> JobStatus and in method Placement method. To avoid code clash with Common.state.JobState
 *
 * Revision 1.10  2005/02/18 16:31:19  mccance
 * Interface update to 2.3.0.
 * Added listRequests method.
 * Added JobState object (jobID, jobState).
 * Changed getJobState to return JobState
 *
 * Revision 1.9  2005/02/07 16:40:33  szamsu
 * merging back from RC1
 *
 * Revision 1.8  2004/11/29 16:20:33  rbritoda
 * updated documentation with proper job and file states
 *
 * Revision 1.7  2004/10/25 14:53:11  mccance
 * add another file state
 *
 * Revision 1.6  2004/10/21 14:08:44  mccance
 * add Finished state for files
 *
 * Revision 1.5  2004/10/05 16:22:41  rbritoda
 * Finished state for file transfers is now called Done
 *
 * Revision 1.4  2004/08/31 08:35:56  mccance
 * Exception n9o longer inherit. Problems with serialization. Getters and Setters removed on all methods - they interfere with the autogenerated setters and getters
 *
 * Revision 1.3  2004/08/20 07:25:13  szamsu
 * For the sake of the carnivore design we got rid of beans.
 *
 * Revision 1.2  2004/07/30 14:37:23  mccance
 * beautify the javadoc.
 *
 * Revision 1.1  2004/07/29 15:32:13  mccance
 * refactored interfaces:
 * filetransfer: internal
 * datascheduler: added, external, matching to LCG
 * fileplacement: extra, same interface as scheduler.
 *
 * Revision 1.1  2004/07/26 11:36:14  mccance
 * Outstanding schoolboy error.. fixed xross module screw up as a result of cp -r with CVS directories...
 *
 * Revision 1.2  2004/07/26 10:27:22  mccance
 * Another iteration after further discussion.
 * Cleaned the iterator impl and renamed a few things.
 *
 * Revision 1.1  2004/07/26 09:50:44  mccance
 * Refactoring interface out of org.glite.data.transfer.
 * Interface updated as a result of discussion with LCG.
 *
 *
 */

package org.glite.data.transfer;

/**
 * Describes the overall status of the job, its state and some extra statistics.
 */
public class TransferJobSummary {
	/**
	 * String containing the current state of the job.
	 */
    public JobStatus jobStatus;

    /**
     * Number of files belonging to the job that are currently in the 'Done' state.
     */
    public int numDone;
    
    /**
     * Number of files belonging to the job that are currently in the 'Active' state.
     */    
    public int numActive;
    
    /**
     * Number of files belonging to the job that are currently in the 'Pending' state.
     */    
    public int numPending;
    
    /**
     * Number of files belonging to the job that are currently in the 'Canceled' state.
     */    
    public int numCanceled;
    
    /**
     * Number of files belonging to the job that are currently in the 'Canceling' state.
     */    
    public int numCanceling;
    
    /**
     * Number of files belonging to the job that are currently in the 'Failed' state.
     */    
    public int numFailed;
    
    /**
     * Number of files belonging to the job that are currently in the 'Finished' state.
     */    
    public int numFinished;
    
    /**
     * Number of files belonging to the job that are currently in the 'Submitted' state.
     */    
    public int numSubmitted;
    
    /**
     * Number of files belonging to the job that are currently in the 'Hold' state.
     */    
    public int numHold;
    
    /**
     * Number of files belonging to the job that are currently in the 'Waiting' state.
     */    
    public int numWaiting;
    
    /**
     * Number of files belonging to the job that are currently in the 'Done' state.
     */    
    public int numCatalogFailed;

    /**
     * Indicates how many files belonging to the job have had to be retried (numRetries > 0).
     */
    public int numRestarted;
}
