/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * File: FileStatus.java
 *         
 * Authors: Gavin McCance <gavin.mccance@cern.ch>
 *
 * Version info: $Id: FileTransferStatus.java,v 1.12 2008/03/17 13:45:37 knienart Exp $
 * Release: $Name:  $
 *
 * Revision history:
 * $Log: FileTransferStatus.java,v $
 * Revision 1.12  2008/03/17 13:45:37  knienart
 * 3.4 additions - targetDirCheck and urlCopyFirstTxmarkTo added
 *
 * Revision 1.11  2005/09/05 14:33:01  rbritoda
 * merge from 1.4
 *
 * Revision 1.10.4.1  2005/09/02 09:06:40  rbritoda
 * duration stays
 *
 * Revision 1.10  2005/07/22 08:55:39  rbritoda
 * updates on documentation. removed not necessary classes in the interface. removed TransferFetcher interface. added setJobPriority method to the FileTransfer/Placement interface.
 *
 * Revision 1.9  2005/07/14 13:31:34  rbritoda
 * changes for new interface. mapping to schema.
 *
 * Revision 1.8  2005/04/04 15:21:33  mccance
 * Upped interface to 2.9.0: removed remove. changed a couple of method names. Added FilePlacement and FilePlacement job
 *
 * Revision 1.7  2005/03/22 14:04:00  mccance
 * Up to version 2.7.1. Added reason_class to FileTransferStatus. Added manual intervention methods on channel management interface for jobs in Held state
 *
 * Revision 1.6  2005/02/22 10:06:00  mccance
 * update docu on interface. State FAILED -> TRANSFERFAILED
 *
 * Revision 1.5  2005/02/07 16:40:33  szamsu
 * merging back from RC1
 *
 * Revision 1.4  2004/11/29 16:20:33  rbritoda
 * updated documentation with proper job and file states
 *
 * Revision 1.3  2004/10/11 14:00:34  mccance
 * extra schema fields added to transfer status - duration and reason
 *
 * Revision 1.2  2004/08/31 08:35:56  mccance
 * Exception n9o longer inherit. Problems with serialization. Getters and Setters removed on all methods - they interfere with the autogenerated setters and getters
 *
 * Revision 1.1  2004/08/20 08:15:43  mccance
 * switch name of filestatus -> filetransferstatus
 *
 * Revision 1.4  2004/08/20 07:25:13  szamsu
 * For the sake of the carnivore design we got rid of beans.
 *
 * Revision 1.3  2004/07/30 14:37:23  mccance
 * beautify the javadoc.
 *
 * Revision 1.2  2004/07/30 14:27:51  mccance
 * added together files for interface
 *
 * Revision 1.1  2004/07/29 15:32:13  mccance
 * refactored interfaces:
 * filetransfer: internal
 * datascheduler: added, external, matching to LCG
 * fileplacement: extra, same interface as scheduler.
 *
 * Revision 1.1  2004/07/26 11:36:14  mccance
 * Outstanding schoolboy error.. fixed xross module screw up as a result of cp -r with CVS directories...
 *
 * Revision 1.2  2004/07/26 10:27:22  mccance
 * Another iteration after further discussion.
 * Cleaned the iterator impl and renamed a few things.
 *
 * Revision 1.1  2004/07/26 09:50:44  mccance
 * Refactoring interface out of org.glite.data.transfer.
 * Interface updated as a result of discussion with LCG.
 *
 *
 */

package org.glite.data.transfer;

/**
 * Describes the status of one file in a transfer job.
 */
public class FileTransferStatus {

    /**
     * The logical name of the file being transfered (only used in the FPS).
     */
    public String logicalName;

    /**
     * The source file for the transfer.
     */
    public String sourceSURL;

    /**
     * The destination file for the transfer.
     */
    public String destSURL;

    /**
     * The current state of the file transfer.
     */
    public String transferFileState;

    /**
     * Number of times this transfer has failed (and retried).
     */
    public int numFailures;

    /**
     * Small explanation on why it went wrong.
     */
    public String reason;

    /**
     * Type of error.
     */
    public String reason_class;

    /**
     * Transfer duration
     */
    public long duration;

}
